==> flashlight-framework-3.1-sources.jar: org/glassfish/flashlight/xml/XmlConstants.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package org.glassfish.flashlight.xml;

/**
 *
 * @author bnevins
 */
public class XmlConstants {
     static String PROBE_PROVIDER = "probe-provider";
     static String MODULE_PROVIDER_NAME = "moduleProviderName";
     static String MODULE_NAME = "moduleName";
     static String PROBE_PROVIDER_NAME = "probeProviderName";
     static String PROBE_PROVIDER_CLASS = "class";
     static String PROBE = "probe";
     static String PROBE_NAME = "name";
     static String PROBE_SELF = "self";
     static String PROBE_HIDDEN = "hidden";
     static String METHOD = "method";
     static String PROBE_PARAM = "probe-param";
     static String PROBE_PARAM_TYPE = "type";
     static String PROBE_PARAM_NAME = "name";
}

==> flashlight-framework-4.0-sources.jar: org/glassfish/flashlight/xml/XmlConstants.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package org.glassfish.flashlight.xml;

/**
 *
 * @author bnevins
 */
public class XmlConstants {
     static String PROBE_PROVIDER = "probe-provider";
     static String MODULE_PROVIDER_NAME = "moduleProviderName";
     static String MODULE_NAME = "moduleName";
     static String PROBE_PROVIDER_NAME = "probeProviderName";
     static String PROBE_PROVIDER_CLASS = "class";
     static String PROBE = "probe";
     static String PROBE_NAME = "name";
     static String PROBE_SELF = "self";
     static String PROBE_HIDDEN = "hidden";
     static String METHOD = "method";
     static String PROBE_PARAM = "probe-param";
     static String PROBE_PARAM_TYPE = "type";
     static String PROBE_PARAM_NAME = "name";
     static String PROBE_STATEFUL = "stateful";
     static String PROBE_STATEFUL_RETURN = "statefulReturn";
     static String PROBE_STATEFUL_EXCEPTION = "statefulException";
     static String PROBE_PROFILE_NAMES = "profileNames";
}
